Module blaxel.models.delete_workspace_service_account_response_200
==================================================================

Classes
-------

`DeleteWorkspaceServiceAccountResponse200(client_id: blaxel.types.Unset | str = <blaxel.types.Unset object>, created_at: blaxel.types.Unset | str = <blaxel.types.Unset object>, description: blaxel.types.Unset | str = <blaxel.types.Unset object>, name: blaxel.types.Unset | str = <blaxel.types.Unset object>, updated_at: blaxel.types.Unset | str = <blaxel.types.Unset object>)`
:   Attributes:
        client_id (Union[Unset, str]): Service account client ID
        created_at (Union[Unset, str]): Creation timestamp
        description (Union[Unset, str]): Service account description
        name (Union[Unset, str]): Service account name
        updated_at (Union[Unset, str]): Last update timestamp
    
    Method generated by attrs for class DeleteWorkspaceServiceAccountResponse200.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `client_id: blaxel.types.Unset | str`
    :

    `created_at: blaxel.types.Unset | str`
    :

    `description: blaxel.types.Unset | str`
    :

    `name: blaxel.types.Unset | str`
    :

    `updated_at: blaxel.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :